pub fn find_null_non_nullable_fields<'a>(
schema: &'a Schema,
values: &[&Value],
) -> Vec<&'a str>Expand description
Returns true if the field is absent from the value’s object map, or explicitly null. Find non-nullable schema fields that are missing or null in any of the given events.